@@ -37,12 +37,13 @@ type StorkAgent struct {
 	logTailer      *logTailer
 	keaInterceptor *keaInterceptor
 	shutdownOnce   sync.Once
+	hookManager    *HookManager
 
 	agentapi.UnimplementedAgentServer
 }
 
 // API exposed to Stork Server.
-func NewStorkAgent(settings *cli.Context, appMonitor AppMonitor) *StorkAgent {
+func NewStorkAgent(settings *cli.Context, appMonitor AppMonitor, hookManager *HookManager) *StorkAgent {
 	logTailer := newLogTailer()
 
 	sa := &StorkAgent{
@@ -51,6 +52,7 @@ func NewStorkAgent(settings *cli.Context, appMonitor AppMonitor) *StorkAgent {
 		HTTPClient:     NewHTTPClient(settings.Bool("skip-tls-cert-verification")),
 		logTailer:      logTailer,
 		keaInterceptor: newKeaInterceptor(),
+		hookManager:    hookManager,
 	}
 
 	registerKeaInterceptFns(sa)
@@ -179,24 +181,25 @@ func (sa *StorkAgent) GetState(ctx context.Context, in *agentapi.GetStateReq) (*
 	}
 
 	state := agentapi.GetStateRsp{
-		AgentVersion:         stork.Version,
-		Apps:                 apps,
-		Hostname:             hostInfo.Hostname,
-		Cpus:                 int64(runtime.NumCPU()),
-		CpusLoad:             loadStr,
-		Memory:               int64(vm.Total / (1024 * 1024 * 1024)), // in GiB
-		UsedMemory:           int64(vm.UsedPercent),
-		Uptime:               int64(hostInfo.Uptime / (60 * 60 * 24)), // in days
-		Os:                   hostInfo.OS,
-		Platform:             hostInfo.Platform,
-		PlatformFamily:       hostInfo.PlatformFamily,
-		PlatformVersion:      hostInfo.PlatformVersion,
-		KernelVersion:        hostInfo.KernelVersion,
-		KernelArch:           hostInfo.KernelArch,
-		VirtualizationSystem: hostInfo.VirtualizationSystem,
-		VirtualizationRole:   hostInfo.VirtualizationRole,
-		HostID:               hostInfo.HostID,
-		Error:                "",
+		AgentVersion:             stork.Version,
+		Apps:                     apps,
+		Hostname:                 hostInfo.Hostname,
+		Cpus:                     int64(runtime.NumCPU()),
+		CpusLoad:                 loadStr,
+		Memory:                   int64(vm.Total / (1024 * 1024 * 1024)), // in GiB
+		UsedMemory:               int64(vm.UsedPercent),
+		Uptime:                   int64(hostInfo.Uptime / (60 * 60 * 24)), // in days
+		Os:                       hostInfo.OS,
+		Platform:                 hostInfo.Platform,
+		PlatformFamily:           hostInfo.PlatformFamily,
+		PlatformVersion:          hostInfo.PlatformVersion,
+		KernelVersion:            hostInfo.KernelVersion,
+		KernelArch:               hostInfo.KernelArch,
+		VirtualizationSystem:     hostInfo.VirtualizationSystem,
+		VirtualizationRole:       hostInfo.VirtualizationRole,
+		HostID:                   hostInfo.HostID,
+		Error:                    "",
+		AgentUsesHTTPCredentials: sa.HTTPClient.HasAuthenticationCredentials(),
 	}
 
 	return &state, nil
@@ -300,6 +303,11 @@ func (sa *StorkAgent) ForwardToNamedStats(ctx context.Context, in *agentapi.Forw
 // Forwards one or more Kea commands sent by the Stork Server to the appropriate Kea instance over
 // HTTP (via Control Agent).
 func (sa *StorkAgent) ForwardToKeaOverHTTP(ctx context.Context, in *agentapi.ForwardToKeaOverHTTPReq) (*agentapi.ForwardToKeaOverHTTPRsp, error) {
+	// Call hook
+	if err := sa.hookManager.OnBeforeForwardToKeaOverHTTP(ctx, in); err != nil {
+		return nil, err
+	}
+
 	// prepare base response
 	response := &agentapi.ForwardToKeaOverHTTPRsp{
 		Status: &agentapi.Status{
@@ -428,7 +436,7 @@ func (sa *StorkAgent) Serve() error {
 	addr := net.JoinHostPort(sa.Settings.String("host"), strconv.Itoa(sa.Settings.Int("port")))
 	lis, err := net.Listen("tcp", addr)
 	if err != nil {
-		return errors.Wrapf(err, "Failed to listen on: %s", addr)
+		return errors.Wrapf(err, "failed to listen on: %s", addr)
 	}
 
 	// Start serving gRPC
@@ -436,7 +444,7 @@ func (sa *StorkAgent) Serve() error {
 		"address": lis.Addr(),
 	}).Infof("Started serving Stork Agent")
 	if err := sa.server.Serve(lis); err != nil {
-		return errors.Wrapf(err, "Failed to serve on: %s", addr)
+		return errors.Wrapf(err, "failed to serve on: %s", addr)
 	}
 	return nil
 }
@@ -449,6 +457,13 @@ func (sa *StorkAgent) Shutdown(reload bool) {
 		if !reload {
 			log.Info("Stopping Stork Agent")
 		}
+		err := sa.hookManager.Close()
+		if err != nil {
+			log.
+				WithError(err).
+				Error("Closing Hook Manager failed")
+		}
+
 		if sa.server != nil {
 			sa.server.GracefulStop()
 		}
