@@ -228,7 +228,7 @@ func TestDecodeAllKeysSubnet4(t *testing.T) {
 	require.Equal(t, "example.org", *params.DDNSQualifyingSuffix)
 	require.Equal(t, "never", *params.DDNSReplaceClientName)
 	require.True(t, *params.DDNSSendUpdates)
-	require.True(t, *params.DDNSUpdateOnReview)
+	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
@@ -355,6 +355,18 @@ func TestGetPrefixSubnet6(t *testing.T) {
 	require.Equal(t, "2001:db8:1:0:0::/64", prefix)
 }
 
+// Test that the IPv4 universe is returned for an IPv4 subnet.
+func TestGetUniverseSubnet4(t *testing.T) {
+	subnet4 := keaconfig.Subnet4{}
+	require.Equal(t, storkutil.IPv4, subnet4.GetUniverse())
+}
+
+// Test that the IPv6 universe is returned for an IPv6 subnet.
+func TestGetUniverseSubnet6(t *testing.T) {
+	subnet6 := keaconfig.Subnet6{}
+	require.Equal(t, storkutil.IPv6, subnet6.GetUniverse())
+}
+
 // Test that the Kea IPv4 subnet configuration parameters are returned
 // in the keaconfig.SubnetParameters union.
 func TestGetParametersSubnet4(t *testing.T) {
@@ -377,7 +389,7 @@ func TestGetParametersSubnet4(t *testing.T) {
 	require.Equal(t, "example.org", *params.DDNSQualifyingSuffix)
 	require.Equal(t, "never", *params.DDNSReplaceClientName)
 	require.True(t, *params.DDNSSendUpdates)
-	require.True(t, *params.DDNSUpdateOnReview)
+	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
@@ -420,7 +432,7 @@ func TestDecodeAllKeysSubnet6(t *testing.T) {
 	require.Equal(t, "example.org", *params.DDNSQualifyingSuffix)
 	require.Equal(t, "never", *params.DDNSReplaceClientName)
 	require.True(t, *params.DDNSSendUpdates)
-	require.True(t, *params.DDNSUpdateOnReview)
+	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
@@ -499,7 +511,7 @@ func TestGetParametersSubnet6(t *testing.T) {
 	require.Equal(t, "example.org", *params.DDNSQualifyingSuffix)
 	require.Equal(t, "never", *params.DDNSReplaceClientName)
 	require.True(t, *params.DDNSSendUpdates)
-	require.True(t, *params.DDNSUpdateOnReview)
+	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
@@ -560,7 +572,7 @@ func TestCreateSubnet4(t *testing.T) {
 	// Subnet prefix.
 	mock.EXPECT().GetPrefix().Return("192.0.2.0/24")
 	// Return a pool defined above.
-	mock.EXPECT().GetAddressPools().Return([]dhcpmodel.AddressPoolAccessor{poolMock})
+	mock.EXPECT().GetAddressPools(gomock.Eq(int64(1))).Return([]dhcpmodel.AddressPoolAccessor{poolMock})
 	// Return subnet-level Kea parameters.
 	mock.EXPECT().GetKeaParameters(gomock.Eq(int64(1))).Return(&keaconfig.SubnetParameters{
 		CacheParameters: keaconfig.CacheParameters{
@@ -750,9 +762,9 @@ func TestCreateSubnet6(t *testing.T) {
 	// Subnet prefix.
 	mock.EXPECT().GetPrefix().Return("2001:db8:1::/64")
 	// Return an address pool defined above.
-	mock.EXPECT().GetAddressPools().Return([]dhcpmodel.AddressPoolAccessor{poolMock})
+	mock.EXPECT().GetAddressPools(gomock.Eq(int64(1))).Return([]dhcpmodel.AddressPoolAccessor{poolMock})
 	// Return a delegated prefix pool defined above.
-	mock.EXPECT().GetPrefixPools().Return([]dhcpmodel.PrefixPoolAccessor{pdPoolMock})
+	mock.EXPECT().GetPrefixPools(gomock.Eq(int64(1))).Return([]dhcpmodel.PrefixPoolAccessor{pdPoolMock})
 	// Return subnet-level Kea parameters.
 	mock.EXPECT().GetKeaParameters(gomock.Eq(int64(1))).Return(&keaconfig.SubnetParameters{
 		CacheParameters: keaconfig.CacheParameters{
