@@ -14,6 +14,7 @@ import (
 	"github.com/urfave/cli/v2"
 	"isc.org/stork"
 	"isc.org/stork/agent"
+	"isc.org/stork/hooks"
 	storkutil "isc.org/stork/util"
 )
 
@@ -43,6 +44,21 @@ func runAgent(settings *cli.Context, reload bool) error {
 		log.Printf("Starting Stork Agent, version %s, build date %s", stork.Version, stork.BuildDate)
 	}
 
+	// Read the hook libraries.
+	hookManager := agent.NewHookManager()
+	err := hookManager.RegisterHooksFromDirectory(hooks.HookProgramAgent, settings.Path("hook-directory"))
+	if err != nil {
+		if errors.Is(err, os.ErrNotExist) {
+			log.
+				WithError(err).
+				Warnf("The hook directory: '%s' doesn't exist", settings.Path("hook-directory"))
+		} else {
+			log.
+				WithError(err).
+				Fatal("Problem with loading hook libraries")
+		}
+	}
+
 	// Try registering the agent in the server using the agent token
 	if settings.String("server-url") != "" {
 		portStr := strconv.FormatInt(settings.Int64("port"), 10)
@@ -55,13 +71,13 @@ func runAgent(settings *cli.Context, reload bool) error {
 	appMonitor := agent.NewAppMonitor()
 
 	// Prepare agent gRPC handler
-	storkAgent := agent.NewStorkAgent(settings, appMonitor)
+	storkAgent := agent.NewStorkAgent(settings, appMonitor, hookManager)
 
 	// Prepare Prometheus exporters
 	promKeaExporter := agent.NewPromKeaExporter(settings, appMonitor)
 	promBind9Exporter := agent.NewPromBind9Exporter(settings, appMonitor)
 
-	err := storkAgent.Setup()
+	err = storkAgent.Setup()
 	if err != nil {
 		log.Fatalf("FATAL error: %+v", err)
 	}
@@ -237,6 +253,12 @@ func setupApp(reload bool) *cli.App {
 				Usage:   "The URL of the Stork Server, used in agent-token-based registration (optional alternative to server-token-based registration)",
 				EnvVars: []string{"STORK_AGENT_SERVER_URL"},
 			},
+			&cli.PathFlag{
+				Name:    "hook-directory",
+				Usage:   "The path to the hook directory",
+				EnvVars: []string{"STORK_AGENT_HOOK_DIRECTORY"},
+				Value:   "/var/lib/stork-agent/hooks",
+			},
 			&cli.BoolFlag{
 				Name:  "use-env-file",
 				Usage: "Read the environment variables from the environment file",
@@ -247,6 +269,14 @@ func setupApp(reload bool) *cli.App {
 				Usage: "Environment file location; applicable only if the use-env-file is provided",
 				Value: "/etc/stork/agent.env",
 			},
+			// Those two parameters are read directly from the environment variable. They're listed here only for
+			// the help.
+			&cli.StringFlag{
+				Name:    "bind9-path",
+				Usage:   "Specify the path to BIND 9 config file. Does not need to be specified, unless the location is very uncommon.",
+				Value:   "",
+				EnvVars: []string{"STORK_BIND9_CONFIG"},
+			},
 			&cli.StringFlag{
 				Name:    "",
 				Usage:   "Logging level can be specified using env variable only. Allowed values: are DEBUG, INFO, WARN, ERROR",
