@@ -12,6 +12,13 @@ type EventsDump struct {
 	machineID int64
 }
 
+// Extended event structure with additional, derived members to improve the
+// dump clarity.
+type EventExtended struct {
+	dbmodel.Event
+	LevelText string
+}
+
 // Constructs new events dump instance.
 func NewEventsDump(db *pg.DB, machine *dbmodel.Machine) *EventsDump {
 	return &EventsDump{
@@ -37,8 +44,16 @@ func (d *EventsDump) Execute() error {
 		return err
 	}
 
+	eventsExtended := make([]EventExtended, len(events))
+	for i, event := range events {
+		eventsExtended[i] = EventExtended{
+			Event:     event,
+			LevelText: event.Level.String(),
+		}
+	}
+
 	d.AppendArtifact(NewBasicStructArtifact(
-		"latest", events,
+		"latest", eventsExtended,
 	))
 	return nil
 }
