@@ -4,12 +4,12 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"strconv"
 	"strings"
 	"testing"
 	"time"
 
 	"github.com/stretchr/testify/require"
+	"isc.org/stork/server/configreview"
 	dbmodel "isc.org/stork/server/database/model"
 	dbtest "isc.org/stork/server/database/test"
 	"isc.org/stork/testutil"
@@ -35,7 +35,7 @@ func getExpectedSwitches() []string {
 		"--rest-max-header-size", "--rest-host", "--rest-port", "--rest-listen-limit",
 		"--rest-keep-alive", "--rest-read-timeout", "--rest-write-timeout", "--rest-tls-certificate",
 		"--rest-tls-key", "--rest-tls-ca", "--rest-static-files-dir", "--initial-puller-interval",
-		"--env-file", "--use-env-file",
+		"--env-file", "--use-env-file", "--db-password",
 	}
 }
 
@@ -75,7 +75,7 @@ func TestCommandLineSwitchesDoc(t *testing.T) {
 	require.True(t, checkOutput(string(man), getExpectedSwitches(), "stork-server.8.rst"))
 }
 
-// This test checks if stork-agent --version (and -v) report expected version.
+// This test checks if stork-server --version (and -v) report expected version.
 func TestCommandLineVersion(t *testing.T) {
 	// Let's repeat the test twice (for -v and then for --version)
 	for _, opt := range []string{"-v", "--version"} {
@@ -165,6 +165,7 @@ func TestNewStorkServer(t *testing.T) {
 		"--rest-tls-ca", "tlsca",
 		"--rest-static-files-dir", "staticdir",
 		"--initial-puller-interval", "54",
+		"--hook-directory", "hookdir",
 	)
 
 	// Act
@@ -174,7 +175,7 @@ func TestNewStorkServer(t *testing.T) {
 	require.NoError(t, err)
 	require.EqualValues(t, RunCommand, command)
 
-	require.True(t, ss.EnableMetricsEndpoint)
+	require.True(t, ss.GeneralSettings.EnableMetricsEndpoint)
 	require.EqualValues(t, "dbname", ss.DBSettings.DBName)
 	require.EqualValues(t, "dbuser", ss.DBSettings.User)
 	require.EqualValues(t, "dbhost", ss.DBSettings.Host)
@@ -197,7 +198,8 @@ func TestNewStorkServer(t *testing.T) {
 	require.EqualValues(t, "tlskey", ss.RestAPISettings.TLSCertificateKey)
 	require.EqualValues(t, "tlsca", ss.RestAPISettings.TLSCACertificate)
 	require.EqualValues(t, "staticdir", ss.RestAPISettings.StaticFilesDir)
-	require.EqualValues(t, 54, ss.InitialPullerInterval)
+	require.EqualValues(t, 54, ss.GeneralSettings.InitialPullerInterval)
+	require.EqualValues(t, "hookdir", ss.GeneralSettings.HookDirectory)
 }
 
 // Test that the Stork Server is not constructed if the arguments are wrong.
@@ -232,7 +234,7 @@ func TestNewStorkServerNoArguments(t *testing.T) {
 // Test that the server is bootstrapped properly.
 func TestBootstrap(t *testing.T) {
 	// Arrange
-	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
+	db, settings, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
 	// Initializes DB.
@@ -259,14 +261,7 @@ func TestBootstrap(t *testing.T) {
 	server, _, _ := NewStorkServer()
 
 	// Switches to test database.
-	server.DBSettings.DBName = db.Options().Database
-	hostAndPort := strings.Split(db.Options().Addr, ":")
-	server.DBSettings.Host = hostAndPort[0]
-	port, _ := strconv.ParseInt(hostAndPort[1], 10, 0)
-	server.DBSettings.Port = int(port)
-	password := db.Options().Password
-	os.Setenv("STORK_DATABASE_PASSWORD", password)
-	server.DBSettings.User = db.Options().User
+	server.DBSettings = *settings
 
 	// Act
 	err := server.Bootstrap(false)
@@ -288,16 +283,37 @@ func TestBootstrap(t *testing.T) {
 
 	// Checks if the config review checker states were loaded from the database.
 	configReviewCheckerPreferences, _ := server.ReviewDispatcher.GetCheckersMetadata(daemons[0])
+	configPreferencesByName := make(map[string]*configreview.CheckerMetadata)
+	for _, preference := range configReviewCheckerPreferences {
+		configPreferencesByName[preference.Name] = preference
+	}
+
 	require.GreaterOrEqual(t, len(configReviewCheckerPreferences), 5)
-	require.EqualValues(t, "host_cmds_presence", configReviewCheckerPreferences[3].Name)
-	require.False(t, configReviewCheckerPreferences[3].GloballyEnabled)
-	require.EqualValues(t, "out_of_pool_reservation", configReviewCheckerPreferences[4].Name)
-	require.True(t, configReviewCheckerPreferences[4].GloballyEnabled)
+	require.Contains(t, configPreferencesByName, "host_cmds_presence")
+	require.False(t, configPreferencesByName["host_cmds_presence"].GloballyEnabled)
+	require.Contains(t, configPreferencesByName, "out_of_pool_reservation")
+	require.True(t, configPreferencesByName["out_of_pool_reservation"].GloballyEnabled)
+
 	configReviewCheckerPreferences, _ = server.ReviewDispatcher.GetCheckersMetadata(daemons[1])
-	require.EqualValues(t, "host_cmds_presence", configReviewCheckerPreferences[3].Name)
-	require.False(t, configReviewCheckerPreferences[3].GloballyEnabled)
-	require.EqualValues(t, "out_of_pool_reservation", configReviewCheckerPreferences[4].Name)
-	require.True(t, configReviewCheckerPreferences[4].GloballyEnabled)
+	configPreferencesByName = make(map[string]*configreview.CheckerMetadata)
+	for _, preference := range configReviewCheckerPreferences {
+		configPreferencesByName[preference.Name] = preference
+	}
+
+	require.Contains(t, configPreferencesByName, "host_cmds_presence")
+	require.False(t, configPreferencesByName["host_cmds_presence"].GloballyEnabled)
+	require.Contains(t, configPreferencesByName, "out_of_pool_reservation")
+	require.True(t, configPreferencesByName["out_of_pool_reservation"].GloballyEnabled)
+
+	// Check the if hook manager is initialized.
+	require.NotNil(t, server.HookManager)
+	require.NotNil(t, server.HookManager.GetExecutor())
+	require.NotEmpty(t, server.HookManager.GetExecutor().GetTypesOfSupportedCalloutSpecifications())
+
+	// Check the if hook manager is initialized.
+	require.NotNil(t, server.HookManager)
+	require.NotNil(t, server.HookManager.GetExecutor())
+	require.NotEmpty(t, server.HookManager.GetExecutor().GetTypesOfSupportedCalloutSpecifications())
 
 	// Run Bootstrap again with the reload flag set.
 	err = server.Bootstrap(true)
@@ -364,5 +380,5 @@ func TestNewStorkServerFromEnvFile(t *testing.T) {
 	require.EqualValues(t, 42, ss.DBSettings.Port)
 	require.EqualValues(t, "bar", ss.DBSettings.DBName)
 	require.EqualValues(t, "baz", ss.RestAPISettings.Host)
-	require.True(t, ss.EnableMetricsEndpoint)
+	require.True(t, ss.GeneralSettings.EnableMetricsEndpoint)
 }
