@@ -1,5 +1,9 @@
 package testutil
 
+import (
+	"os"
+)
+
 // This function always returns the same content. It is intended
 // to avoid breaking IDE syntax highlighting (problem occurs on vscode).
 func GetCACertPEMContent() []byte {
@@ -132,3 +136,28 @@ TjJxMspTfL1UmI4vXP68tYRvThQbNNJxOviNmV0XBiKgQW5bD01j/KwpAD3/8ean
 wQ==
 -----END CERTIFICATE-----`)
 }
+
+// Creates the certificate, key and CA certificate for testing
+// secure database connections.
+func CreateTestCerts(sb *Sandbox) (serverCert, serverKey, rootCert string, err error) {
+	serverCert, err = sb.Write("server-cert.pem", string(GetCertPEMContent()))
+	if err != nil {
+		return "", "", "", err
+	}
+
+	serverKey, err = sb.Write("server-key.pem", string(GetKeyPEMContent()))
+	if err != nil {
+		return "", "", "", err
+	}
+	err = os.Chmod(serverKey, 0o600)
+	if err != nil {
+		return "", "", "", err
+	}
+
+	rootCert, err = sb.Write("root-cert.pem", string(GetCACertPEMContent()))
+	if err != nil {
+		return "", "", "", err
+	}
+
+	return serverCert, serverKey, rootCert, nil
+}
