@@ -243,6 +243,12 @@ func GetSecretInTerminal(prompt string) (string, error) {
 	return string(pass), nil
 }
 
+// Checks if the current process is running in a terminal.
+func IsRunningInTerminal() bool {
+	descriptor := int(os.Stdin.Fd())
+	return term.IsTerminal(descriptor)
+}
+
 // Read a file and resolve all include statements.
 func ReadFileWithIncludes(path string) (string, error) {
 	parentPaths := map[string]bool{}
@@ -266,9 +272,8 @@ func readFileWithIncludes(path string, parentPaths map[string]bool) (string, err
 	// - Path may be relative to parent file or absolute
 	// - Path must be escaped with double quotes
 	// - May to contains spacing before and after the path quotes
-	// - Path must contain ".json" extension
 	// Produce two groups: first for the whole statement and second for path.
-	includePattern := regexp.MustCompile(`<\?include\s*\"([^"]+\.json)\"\s*\?>`)
+	includePattern := regexp.MustCompile(`<\?include\s*\"([^"]+\..*)\"\s*\?>`)
 	matchesGroupIndices := includePattern.FindAllStringSubmatchIndex(text, -1)
 	matchesGroups := includePattern.FindAllStringSubmatch(text, -1)
 
