@@ -1,7 +1,13 @@
+import pytest
+
 from core.fixtures import kea_parametrize
 from core.wrappers import Server, Kea
 
 
+@pytest.mark.skip(
+    reason="The test is unstable because it doesn't wait to finish loading "
+           "the Kea configuration. Unlike other tests, the loading here takes "
+           "too much time and crashes the execution.")
 @kea_parametrize("agent-kea-many-subnets")
 def test_add_kea_with_many_subnets(server_service: Server, kea_service: Kea):
     """Check if Stork agent and server will handle Kea instance with huge amount of subnets."""
