@@ -114,7 +114,7 @@ describe('KeaDaemonConfigurationPageComponent', () => {
             } as any)
         )
 
-        authService.login('foo', 'bar', 'baz')
+        authService.login('boz', 'foo', 'bar', 'baz')
 
         fixture = TestBed.createComponent(KeaDaemonConfigurationPageComponent)
         component = fixture.componentInstance
