@@ -1,6 +1,8 @@
-import { Component, OnInit } from '@angular/core'
+import { Component, OnDestroy, OnInit } from '@angular/core'
 import { AuthService } from '../auth.service'
 import { ServerDataService } from '../server-data.service'
+import { User } from '../backend'
+import { Subscription } from 'rxjs'
 
 /**
  * This component is for displaying information about the user's account.
@@ -10,17 +12,24 @@ import { ServerDataService } from '../server-data.service'
     templateUrl: './profile-page.component.html',
     styleUrls: ['./profile-page.component.sass'],
 })
-export class ProfilePageComponent implements OnInit {
+export class ProfilePageComponent implements OnInit, OnDestroy {
     breadcrumbs = [{ label: 'User Profile' }]
 
-    currentUser = null
+    currentUser: User = null
     private groups: any[]
     public groupName: string
 
+    /**
+     * List of subscriptions created by the component.
+     */
+    private subscriptions = new Subscription()
+
     constructor(private auth: AuthService, private serverData: ServerDataService) {
-        this.auth.currentUser.subscribe((x) => {
-            this.currentUser = x
-        })
+        this.subscriptions.add(
+            this.auth.currentUser.subscribe((user) => {
+                this.currentUser = user
+            })
+        )
     }
 
     /**
@@ -38,6 +47,13 @@ export class ProfilePageComponent implements OnInit {
         })
     }
 
+    /**
+     * Unsubscribe the subscriptions.
+     */
+    ngOnDestroy(): void {
+        this.subscriptions.unsubscribe()
+    }
+
     /**
      * Returns header of the panel with user profile data.
      *
@@ -46,9 +62,9 @@ export class ProfilePageComponent implements OnInit {
      * them is returned (typically the case for the admin account).
      */
     public get profilePanelHeader(): string {
-        let hdr = this.currentUser.firstName
-        if (this.currentUser.firstName !== this.currentUser.lastName) {
-            hdr += ' ' + this.currentUser.lastName
+        let hdr = this.currentUser.name
+        if (this.currentUser.name !== this.currentUser.lastname) {
+            hdr += ' ' + this.currentUser.lastname
         }
         return hdr
     }
